<?php

namespace Drupal\darkmode\Form;

use Drupal\Core\Config\ConfigFactoryInterface;
use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Implements a codimth Config Form API.
 */
class DarkmodeConfigurationForm extends ConfigFormBase {

  /**
   * The config factory.
   *
   * @var \Drupal\Core\Config\ConfigFactoryInterface
   */
  private ConfigFactoryInterface $config;

  /**
   * Constructs a ConfigForm object.
   *
   * @param \Drupal\Core\Config\ConfigFactoryInterface $config_factory
   *   The factory for configuration objects.
   */
  public function __construct(ConfigFactoryInterface $config_factory) {
    $this->config = $config_factory;
    parent::__construct($config_factory);
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container) {
    return new static(
      $container->get('config.factory'),
    );
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'darkmode_options_settings';
  }

  /**
   * Gets the configuration names that will be editable.
   *
   * @return array
   *   An array of configuration object names that are editable if called in
   *   conjunction with the trait's config() method.
   */
  protected function getEditableConfigNames() {
    return [
      'darkmode.options_settings',
    ];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('darkmode.config');

    $form['bottom'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Bottom'),
      '#default_value' => $config->get('bottom') ?? $config->get('bottom'),
      '#description' => $this->t('Enter number of pixel for Bottom or unset'),
    ];
    $form['right'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Right'),
      '#default_value' => $config->get('right') ?? $config->get('right'),
      '#description' => $this->t('Enter number of pixel for Right or unset'),
    ];

    $form['left'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Left'),
      '#default_value' => $config->get('left') ?? 'unset',
      '#description' => $this->t('Enter number of pixel for Left or unset'),
    ];

    $form['time'] = [
      '#type' => 'textfield',
      '#title' => $this->t('Time'),
      '#default_value' => ($config->get('time') == '') ? '0.5s' : $config->get('time'),
      '#description' => $this->t('Enter number of Seconds'),

    ];
    $form['mixColor'] = [
      '#type' => 'textfield',
      '#title' => $this->t('MixColor'),
      '#default_value' => $config->get('mixColor') ?? '#fff',
      '#description' => $this->t('Enter the color code Ex: #fff'),

    ];
    $form['backgroundColor'] = [
      '#type' => 'textfield',
      '#title' => $this->t('BackgroundColor'),
      '#default_value' => $config->get('backgroundColor') ?? '#fff',
      '#description' => $this->t('Enter the color code Ex: #fff'),
    ];
    $form['buttonColorDark'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ButtonColorDark'),
      '#default_value' => $config->get('buttonColorDark') ?? '#100f2c',
      '#description' => $this->t('Enter the color code Ex: #fff'),
    ];
    $form['buttonColorLight'] = [
      '#type' => 'textfield',
      '#title' => $this->t('ButtonColorLight'),
      '#default_value' => $config->get('buttonColorLight') ?? '#fff',
      '#description' => $this->t('Enter the color code Ex: #fff'),
    ];
    $form['saveInCookies'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('SaveInCookies'),
      '#default_value' => $config->get('saveInCookies') ?? FALSE,
    ];

    $form['autoMatchOsTheme'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('AutoMatchOsTheme'),
      '#default_value' => $config->get('autoMatchOsTheme') ?? TRUE,
    ];
    return parent::buildForm($form, $form_state);
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $this->config->getEditable('darkmode.config')
      ->set('bottom', $form_state->getValue('bottom'))
      ->set('right', $form_state->getValue('right'))
      ->set('left', $form_state->getValue('left'))
      ->set('time', $form_state->getValue('time'))
      ->set('mixColor', $form_state->getValue('mixColor'))
      ->set('backgroundColor', $form_state->getValue('backgroundColor'))
      ->set('buttonColorDark', $form_state->getValue('buttonColorDark'))
      ->set('buttonColorLight', $form_state->getValue('buttonColorLight'))
      ->set('saveInCookies', boolval($form_state->getValue('saveInCookies')))
      ->set('autoMatchOsTheme', boolval($form_state->getValue('autoMatchOsTheme')))
      ->save();
  }

}
